@@ -134,6 +134,239 @@ class DVPOAuth:
         _, resp = self.call_eligibility(account)
         return True if resp["d"]["ZDSMInquiry"]["RejectionReasonDsm"] == "" else False
 
+    def convert_account_retrieve_from_oauth_to_soap(self, status_code=None, resp=None):
+# resp = 
+# {
+#    "__metadata":{
+#       "id":"http://sapiuqapp01.dominionnet.com:8001/sap/opu/odata/sap/ZISU_UMC_DSM_SRV/ZAcctSearchAndRetrieveSet('RETRACCT')",
+#       "uri":"http://sapiuqapp01.dominionnet.com:8001/sap/opu/odata/sap/ZISU_UMC_DSM_SRV/ZAcctSearchAndRetrieveSet('RETRACCT')",
+#       "type":"ZISU_UMC_DSM_SRV.ZAcctSearchAndRetrieve"
+#    },
+#    "RETRACCTData":{
+#       "__metadata":{
+#          "type":"ZISU_UMC_DSM_SRV.RetrAcctData"
+#       },
+#       "AccountClass":"Z001",
+#       "AccountCloseDate":"None",
+#       "AccountRepFlag":"",
+#       "AccountRepName":"",
+#       "AccountActive":"Y",
+#       "AccountType":"MM",
+#       "AcctOpenDate":"/Date(1661817600000)/",
+#       "ActivityTimestamp":"/Date(1676927897000)/",
+#       "AdditionalAddressInfo":"",
+#       "AlternateRate":"",
+#       "AltMailAddrSeq":"",
+#       "BillAccountStatusCode":"A",
+#       "BillCycle":"01",
+#       "CodeNpso":"",
+#       "CollectionAgencyStatus":"",
+#       "CurrentConversationId":"",
+#       "CustomerId":"1102679581",
+#       "CustomerName1":"DAVID ALLEN ASHLEY",
+#       "CustomerName2":"",
+#       "CustomerName3":"",
+#       "CustomerName4":"",
+#       "CustomerName5":"",
+#       "CustomerPin1":"",
+#       "CustomerPin2":"",
+#       "CustomerPin3":"",
+#       "CustomerPin4":"",
+#       "CustomerPin5":"",
+#       "CustomerSsn1":"7815",
+#       "CustomerSsn2":"",
+#       "CustomerSsn3":"",
+#       "CustomerSsn4":"",
+#       "CustomerSsn5":"",
+#       "DateEndMm":"",
+#       "DateEndYyyy":"",
+#       "DateStartMm":"",
+#       "DateStartYyyy":"",
+#       "DelinquencyIndicator":"N",
+#       "FederalTaxId":"",
+#       "InternetUserId":"",
+#       "MailAddrCity":"POWHATAN",
+#       "MailAddrDateEffective":"None",
+#       "MailAddrDateTerm":"None",
+#       "MailAddrDirection":"",
+#       "MailAddrDirSuffix":"",
+#       "MailAddrHouseMod":"",
+#       "MailAddrHouseNumber":"3845",
+#       "MailAddrModifier":"",
+#       "MailAddrName":"",
+#       "MailAddrNonStd1":"",
+#       "MailAddrNonStd2":"",
+#       "MailAddrNonStd3":"",
+#       "MailAddrState":"VA",
+#       "MailAddrStreetName":"WILDWOOD SHORES CT",
+#       "MailAddrStreetType":"",
+#       "MailAddrZipcode":"23139",
+#       "MailAddrZipSuffix":"7071",
+#       "NameCustFirst":"DAVID",
+#       "NameCustLast":"ASHLEY",
+#       "NameCustMiddle":"ALLEN",
+#       "Password":"",
+#       "PasswordIndicator":"N",
+#       "Phone":"",
+#       "PhoneAreaCode":"",
+#       "PhoneExt":"",
+#       "PhoneNumberSeq":"",
+#       "PremiseId":"0088149407",
+#       "RateCode":"VR-1",
+#       "RateCodeDescription":"VA Resi Sch-1",
+#       "RevenueClass":"",
+#       "ServicePointId":"7002804335",
+#       "ServicePointSpecialUse":"",
+#       "SpecialContractDemand":"",
+#       "SvcAddrCardinalDir":"",
+#       "SvcAddrCity":"POWHATAN",
+#       "SvcAddrCountry":"US",
+#       "SvcAddrDirSuffix":"",
+#       "SvcAddrHouse":"3845",
+#       "SvcAddrHouseMod":"",
+#       "SvcAddrModifier":"",
+#       "SvcAddrSt":"VA",
+#       "SvcAddrStreetName":"WILDWOOD SHORES CT",
+#       "SvcAddrStreetSuffix":"",
+#       "SvcAddrZip":"23139",
+#       "SvcAddrZipSuffix":"7071",
+#       "TerminalId":"",
+#       "TownCode":"0500",
+#       "Contract":"",
+#       "UserId":"",
+#       "MailingAddress":{
+#          "__metadata":{
+#             "type":"ZISU_UMC_DSM_SRV.ZContractAccMaintMailAdress"
+#          },
+#          "CareOf":"",
+#          "City":"POWHATAN",
+#          "Country":"US",
+#          "HouseNum1":"3845",
+#          "HouseNum2":"",
+#          "InternationAddrx":"",
+#          "Location":"",
+#          "MailingaddrType":"ST",
+#          "PoBoxAdress":"",
+#          "Region":"VA",
+#          "Street":"WILDWOOD SHORES CT",
+#          "ZipCode":"23139-7071",
+#          "InternationAddr":{
+#             "__metadata":{
+#                "type":"ZISU_UMC_DSM_SRV.ZmailingAddr"
+#             },
+#             "Line1":"",
+#             "Line2":"",
+#             "Line3":"",
+#             "Line4":"",
+#             "Line5":"",
+#             "Line6":""
+#          }
+#       }
+#    },
+#    "SearchType":"",
+#    "InternetFunctionCode":"RETRACCT",
+#    "UserId":"",
+#    "CallingApplication":"",
+#    "QuantityRowsRequested":0,
+#    "AreaCode":"",
+#    "PhoneNumber":"",
+#    "Email":"",
+#    "OfficeCode":"",
+#    "TownCode":"",
+#    "CustomerFirstName":"",
+#    "CustomerMidName":"",
+#    "CustomerLastName":"",
+#    "CorporateName":"",
+#    "HouseNumber":"",
+#    "HouseNumberMod":"",
+#    "CardinalDirection":"",
+#    "StreetName":"",
+#    "StreetType":"",
+#    "DirectionSuffix":"",
+#    "AddressModifier":"",
+#    "City":"",
+#    "State":"",
+#    "Zip":"",
+#    "Meter":"",
+#    "Premise":"",
+#    "FederalTaxId":"",
+#    "SSN":"",
+#    "Pin":"",
+#    "BusinessPartner":"",
+#    "BillAccount":"000889103594",
+#    "ActiveBaOnly":"",
+#    "ServiceAccountsOnly":"",
+#    "InternetReturnCode":"S",
+#    "ReturnMessageText":"Business Account details retrived successfully!",
+#    "ResultCode":"00",
+#    "ErrorCode":"",
+#    "ActiveTimeStamp":"/Date(1676927897000)/",
+#    "MoreData":"N",
+#    "RowsReturned":1,
+#    "ZAcctSearchNav":{
+#       "results":[
+         
+#       ]
+#    },
+#    "ZRetrContractsNav":{
+#       "__deferred":{
+#          "uri":"http://sapiuqapp01.dominionnet.com:8001/sap/opu/odata/sap/ZISU_UMC_DSM_SRV/ZAcctSearchAndRetrieveSet('RETRACCT')/ZRetrContractsNav"
+#       }
+#    }
+# }
+        data = resp['d']['results'][0]
+        res = {
+            'AccountNumber': data['BillAccount'],
+            'AccountStatusCode': data['RETRACCTData']['BillAccountStatusCode'],
+            'AccountType': data['RETRACCTData']['AccountType'],
+            'BusinessName': None,
+            'FirstName': data['RETRACCTData']['NameCustFirst'],
+            'Header': {
+                'DateTimeStamp': datetime.now().strftime("%Y-%m-%d-%H.%M.%S.%f"),
+                'MessageText': data['ReturnMessageText'],
+                'Result': data['InternetReturnCode'],
+                'ReturnCode': data['ErrorCode']
+            },
+            'LastName': data['RETRACCTData']['NameCustLast'],
+            'LastSmartCoolCreditAmt': None,
+            'LastSmartCoolCreditDate': None,
+            'Latitude': None,
+            'Longitude': None,
+            'MailingAddressCity': data['RETRACCTData']['MailAddrCity'],
+            'MailingAddressLine1': data['RETRACCTData']['MailAddrStreetName'],
+            'MailingAddressState': data['RETRACCTData']['MailAddrState'],
+            'MailingAddressZipCode': data['RETRACCTData']['MailAddrZipcode'],
+            'MedicalFlag': None,
+            'MiddleName': data['RETRACCTData']['NameCustMiddle'],
+            'NameSuffix': None,
+            'NonStandardAddressLine1': None,
+            'NonStandardAddressLine2': None,
+            'NonStandardAddressLine3': None,
+            'OfficeCode': data['RETRACCTData']['TownCode'],
+            'OpenAccess': None,
+            'OptOut': None,
+            'OtherAccountNames': None,
+            'PremiseId': data['RETRACCTData']['PremiseId'],
+            'PremisePhoneAreaCode': data['RETRACCTData']["PhoneAreaCode"],
+            'PremisePhoneNumber': data['RETRACCTData']["Phone"],
+            'ServiceAddressLine1': None,
+            'ServiceCity': data['RETRACCTData']['SvcAddrCity'],
+            'ServicePoint': {
+                'ServicePoint': [
+                    {
+                        'AmiMeter': None,
+                        'MeterNumber': None,
+                        'RateCode': None,
+                    }
+                ]
+            },
+            'ServiceState': data['RETRACCTData']["SvcAddrSt"],
+            'ServiceZipCode': data['RETRACCTData']["SvcAddrZip"],
+            'SwitchActive': None,
+            'SwitchInstalled': None
+        }
+        return res
+
     def convert_eligibility_json_from_oauth_to_soap(self, status_code=None, resp=None):
         """convert the oauth return the the soap format"""
         data = resp["d"]["ZDSMInquiry"]
@@ -394,3 +627,5 @@ class DVPOAuth:
             logger.info(f"Search response : {resp}")
 
         return resp_query.status_code, resp
+
+
